@@ -457,14 +457,13 @@ def main():
   parser.add_option('--selectLimit', dest='selectLimit', default=0, type='int', help='Select top n model')
 
   (options,args) = parser.parse_args()
-  print(options)
-  print(args)
-
   if len(args) < 1:
     print('Input format: CSV by --delimiter: len(rocord)==4. Ex: modelId, weight, score, label')
     parser.print_help()
     exit(1)
 
+  print('Options:', options)
+  print('Args:', args)
   roc(args[0], options.phrase)
 
 if __name__ == '__main__':
